#!/etc/opt/openit/perl

use strict;

use File::Copy;

print "Patching openit.env with updates for library paths.\n";

my $file = "/etc/opt/openit/openit.env";
my $tmp = "$file.tmp";

open( FILE, "<$file" ) or die "Failed to read input $file: $!\n";
my @lines;
my $line = readline( FILE );
while( defined $line ) {
	push @lines, $line;
	$line = readline( FILE );
}
if( $! ) {
	warn "Failed to read line from $file: $!\n";
	close( FILE );
	die;
}
close( FILE );

my $arch;
foreach my $line( @lines ) {
	chomp $line;
	if( $line =~ m/^OPENIT_ARCH=(.*)$/ ) {
		$arch = $1;
	}
	if( $line =~ m#^LD_LIBRARY_PATH=/opt/openit# ) {
		print "File seems to be patched already. Skipping.\n";
		exit( 0 );
	}
}

if( ! defined $arch ) {
	die "Failed to find archictecture.\n";
}

my $lib_dir = "/opt/openit/libexec/$arch/lib";

foreach my $line( @lines ) {
	if( $line =~ m#^LD_LIBRARY_PATH=\$# ) {
		$line = "LD_LIBRARY_PATH=$lib_dir:\$LD_LIBRARY_PATH:/usr/openwin/lib";
	} elsif( $line =~ m#^SHLIB_PATH=\$# ) {
		$line = "SHLIB_PATH=$lib_dir:\$SHLIB_PATH:/usr/openwin/lib";
	} elsif( $line =~ m#^LIBPATH=# ) {
		$line = "LIBPATH=$lib_dir:\$LIBPATH";
	}
}

open( TMP, ">$tmp" ) or die "Failed to open output $tmp: $!\n";
foreach my $line( @lines ) {
	if( ! print TMP "$line\n" ) {
		warn "Failed to write to $tmp: $!\n";
		close( TMP );
		die;
	}
}
close( TMP );

if( ! &File::Copy::copy( $file, "$file.orig" ) ) {
	die "Failed to make security copy of $file: $!\n";
}
if( ! rename( $tmp, $file ) ) {
	if( ! &File::Copy::copy( "$file.orig", $file ) ) {
		warn "Failed to copy backup $file: $!\n";
	}
	die "Failed to rename $tmp to $file: $!\n";
}
print "Updated openit.env.\n";
exit( 0 );
